[![Build Status](https://travis-ci.com/hasii2011/OrthogonalDrawing.svg?branch=master)](https://travis-ci.com/hasii2011/OrthogonalDrawing)

[![PyPI version](https://badge.fury.io/py/orthogonal.svg)](https://badge.fury.io/py/orthogonal)



# Orthogonal Drawing Algorithm

This project is a fork of [this project.](https://github.com/rawfh/orthogonal-drawing-algorithm)

